==> 2.9.zip: piwigo/language/en_US/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: English [US]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=717
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "English";
$lang_info['country'] = "United States";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "en";
$lang_info['zero_plural'] = true;
$lang_info['parent']= "en_UK";


$lang['Please, enter a login'] = 'Please enter a login';
$lang['Password reset is not allowed for this user'] = 'Password reset is not allowed for this user.';
$lang['Piwigo encountered a non recoverable error'] = 'Piwigo encountered an unrecoverable error.';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood system: please wait a moment before trying to post another comment.';
$lang['An administrator must authorize your comment before it is visible.'] = 'An administrator must authorize your comment before it is displayed.';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Bad status for guest user; default status will be used. Please notify the webmaster.';

==> 14.5.0.zip: piwigo/language/en_US/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
/*
Language Name: English [US]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=717
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "English";
$lang_info['country'] = "United States";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "en";
$lang_info['zero_plural'] = true;
$lang_info['parent']= "en_UK";


$lang['Please, enter a login'] = 'Please enter a login';
$lang['Password reset is not allowed for this user'] = 'Password reset is not allowed for this user.';
$lang['Piwigo encountered a non recoverable error'] = 'Piwigo encountered an unrecoverable problem.';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood system: please wait a moment before trying to post another comment.';
$lang['An administrator must authorize your comment before it is visible.'] = 'An administrator must authorize your comment before it is displayed.';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Bad status for guest user; default status will be used. Please notify the webmaster.';
